(* O(n log(n)) solution to the problem "Intervals"                                         *)
(* We sort the intervals increasingly by b_i-s and then process them one at a time         *)
(* in that order. We choose the numbers contained in the set Z to be as large as possible. *)
(* Simple argument shows that this method gives the optimal solution.                      *)
(* There are two minor problems to solve at this point. First, when we pick an interval    *)
(* we would like to know how many numbers in that interval are already in Z. And second,   *)
(* it seems that we would also like to know which numbers are these.                       *)
(* We use the following solution to these problems: The numbers chosen after processing    *)
(* the first k intervals, form at most k integer intervals themselves. We keep these       *)
(* in an array. Now, when we want to know which intervals have nonempty intersection       *)
(* with the current interval, we can find it out in time O(log(n)) using binary search.    *)
(* In order to be able to compute the total number of the elements in these intervals,     *)
(* we also keep the appropriate partial sums array. For details, see procedure compute_z   *)
(*                                                                                         *)
(* Written by: Marcin Mucha, mucha@mimuw.edu.pl                                            *)

const
   N_MAX =  50000;

type
   number   = word;
   interval = record a, b, c : number end;

var
   ints	: array[1..N_MAX] of interval;
   n	: number;

procedure sort_ints;

   procedure xchg(var u, v : interval);
   var
      w	: interval;
   begin
      w := u; u := v; v := w
   end; { xch }

   function larger(var u, v : interval) : boolean;
   begin
      if (u.b > v.b) then
	 larger := true
      else if (u.b = v.b) and (u.c < v.c) then { a little speed-up }
	 larger := true
      else
	 larger := false;
   end;

   procedure downheap(i, bottom : number);
   var
      tmp : number;
   begin
      while (2*i <= bottom) do
      begin
	 { recall that the heap has the largest elements on top }
	 if larger(ints[2*i],ints[i]) then tmp := 2*i else tmp := i;
	 if (2*i+1 <= bottom) and larger(ints[2*i+1],ints[tmp]) then tmp := 2*i+1;
	 if (tmp = i) then break;
	 xchg(ints[i],ints[tmp]);
	 i := tmp;
      end;
   end; { downheap }

var
   i : number;
begin
   for i := n downto 1 do downheap(i,n);
   for i := n downto 2 do
   begin
      xchg(ints[1],ints[i]);
      downheap(1,i-1)
   end;
end; { sort_ints }

function compute_z : word;
var
   z	  : array[1..N_MAX] of interval; { these are the intervals of numbers in Z }
   psum	  : array[0..N_MAX] of number; { partial sums of the sizes of the intervals in Z }
   zn	  : number; { number of intervals in Z }
   needed : longint;

   function count_from(x : number) : word;
   var
      i	    : number;
      count : number;

      procedure find_i;
      { Finds the last interval in Z that is not totally contained in the current interval }
      var
	 j, k, l : number;
      begin
	 if zn = 0 then
	    i := 0
	 else if (z[1].a >= x) then
	    i := 0
	 else if (z[zn].a < x) then
	    i := zn
	 else
	 begin
	    j := 1; k := zn;
	    while (k-j>1) do
	    begin
	       l := (j+k) div 2;
	       if z[l].a >= x then k := l else j := l
	    end;
	    i := j;
	 end;
      end;

   begin
      find_i;
      count := psum[zn]-psum[i];
      if (i>0) and (z[i].b >= x) then inc(count,z[i].b+1-x);
      count_from := count;
   end; { count }

var
   i, j	: number;

begin
   zn := 0; psum[0] := 0;
   for i := 1 to n do
   begin
      needed := ints[i].c - count_from(ints[i].a);
      if needed <= 0 then continue;
      { how many intervals do we have to join }
      j := zn;
      while (j>0) and ((ints[i].b-z[j].b)-(psum[zn]-psum[j]) <= needed) do dec(j);
      { replace them with one new interval }
      z[j+1].b := ints[i].b;
      z[j+1].a := ints[i].b+1-needed-(psum[zn]-psum[j]);
      psum[j+1] := psum[j] + z[j+1].b + 1 - z[j+1].a;
      zn := j+1;
   end;
   compute_z := psum[zn];
end; { compute_z }

var
   i : number;

begin
   readln(n);
   for i := 1 to n do readln(ints[i].a, ints[i].b, ints[i].c);
   sort_ints;
   writeln(compute_z);
end.