
/* contest: 2002 ACM CEPC, Warsaw
 * problem: "One way traffic"
 * solution: O(n^2) - acceptable solution
 * author: Marcin Stefaniak 
 * date: 22.10.2002
 */

/* solution description:

	the solution idea is due to the problem's author, Bartek Walczak

	the traffic network is a graph of n vertices and m edges.
	
	the graph is represented in memory as matrix e[u][v]

	we perform a dfs-search, and obtain a dfs tree T spanning the whole graph.
	let us denote by f[v] the time of processing vertex v (post-order)
	let us denote by TP[v] parent of v in T;
	
	consider an undirected edge u--v. If it belongs to T, TP[v]==u, then we direct it
	"leafwards", i.e towards leafs, u->v. 	
	it is possible that in future we'll  reverse or make it a bridge, if it appears necessary
	we call such an edge "half-directed"
	
	if u--v is not a tree edge, f[u]<f[v], 
	then it must be a "backward" edge, i.e. v is an ancestor of u, 
	so we direct it "rootwards", u->v, cause there is a path u-->v 
	(although we will revert some tree edges afterwards, the path stays clears)
	
	the following properties apply to T now and for the rest of the algorithm:
	
	(1) subtree rooted at v contains vertices w such that f[w] comes from interval <x;f[v]> and no others
	(2) if there is an edge u->v and f[u]<f[v], then u->v is a backward edge in the T
	(3) half-directed edges are tree edges
	(4) graph is strongly connected, provided that half-directed edges can be travelled both ways
	
	note, that every backward edge in dfs tree implies a set of vertices from the same 
	strongly connected component, hence we could merge these into one component
	
	we make a list L of all vertices ordered by f[] ascending. 
	From now L reflects the post-order of T. We'll change L whenever we change T.
	
	In loop, let v be the first of L

		there are three cases:

		case 1): there is an edge from v (v->u). 

			since (2) it must be a backward edge, so
			we merge all vertices on path u--->v into one vertex u' 
		    such that f[u'] = f[u] (i.e. we remove earlier vertices from L)
				
		case 2): there is no edge from v (v->u), and there is only one edge to v (u->v) 
				
			the (u->v) is a tree edge
		  since (3) and (4) the edge (u->v) is half-directed.
			since there is no way to reach v from root other then by this edge, it must be a bridge
			well, let it be a bridge then, and forget v (remove it from L)
			
		case 3): there is no edge from v (v->u), and there are >= 2 edges to v 
		
		  let (u->v) be the tree edge, and (w->v) a non-tree edge, such that w is earliest (on L)
			  (of course w is later than v)
			
			since (3) and (4) (u->v) is half-directed.
			we reverse it, thus obtaining an edge (v->u) 
			the edge (w->v) becomes a tree egde,
			and v is moved on L just before w (so (1) holds)
			note, that since (1)
			  if w is earlier than u, then edge (v->u) becomes a backward edge, 
				so (2) is still true

	We repeat the loop until |L| == 1

	Since in case 1) we merge some vertices, and in 2) i 3) one half-directed edge is gone 
	(there is at most n-1 half-directed edges), there would be at most 2n turns of the loop.		
	Each turn of loop could be made in time O(n),
	Therefore it is an O(n^2) solution
	
 */

using namespace std;
 
#include <stdio.h>

#include<algorithm>
#include<iostream>
#include<vector>
#include<bitset>
#include<deque>

#define REP(i, n) for(int i=0;i<(n);i++)
#define FOR(i, a, b) for(int i=(a);i<=(b);i++)
#define VAR(zm, wyr) typeof((wyr)) zm = (wyr)
#define FOREACH(it, kol) for(VAR(it, (kol).begin()); it!=(kol).end(); ++it)

const int MAXN = 2000;

int n, m;

bitset<1+MAXN> e[1+MAXN];

void read_data() {
	int a, b, c;
	
	scanf("%d %d", &n, &m);

	FOR(a,0,n) FOR(b,0,n) e[a][b] = false;

	REP(i, m) {
		scanf("%d %d %d", &a, &b, &c);
		e[a][b] = true;
		if (c==2)	e[b][a] = true;
	}
}

int T[1+MAXN]; // dfs tree (parents array)
bool half_directed[1+MAXN]; // if v--T[v] was marked as half directed edge

deque<int> L; // vertices listed by post-order
bool removed[1+MAXN]; // if vertex was removed from L
	
bool visited[1+MAXN]; // used by dfs

void output(int a, int b, int c) {
	printf("%d %d %d\n", a, b, c);
}

void T_dfs(int u) {
	visited[u] = true;
	FOR(v,1,n) if (e[u][v]) {
		if (!visited[v]) {
			if (e[v][u]) { 
				e[v][u] = false; // a half-directed edge ...
				half_directed[v] = true;
			}
			T[v] = u;				
			T_dfs(v);
		} else 
			if (e[v][u]) { 
				e[v][u] = false; // this will go rootwards
				output(u, v, 1);
			}
	}
	L.push_back(u);
}
	
void solve() {

	FOR(a,0,n) T[a] = visited[a] = removed[a] = half_directed[a] = 0;
	L.clear();
	T_dfs(1);
	
	int cnt = 0; // the loop should end in less then 2n turns, but in case sth goes wrong...
	while (L.size() > 1 && ++cnt <= 2*n) { 
	
		int v = *(L.begin());
		bool cont = false;

		FOR(u,1,n) if (!removed[u] && e[v][u]) { 		// look for edges from v
			// case 1) -- merge vertices v, T[v], ... , u
			int a=v; while (a!=u) {
				int p = T[a]; T[a] = u;
				if (!removed[a]) {
					if (half_directed[a]) {
						output(p, a, 1); // half-directed edge was directed ok
						// half_directed[v] = false; // unneccessary
					}
					FOREACH(it, L) if (*it==a) { L.erase(it); break; }
					removed[a] = true;
					FOR(b,1,n) if (e[a][b] && b!=u) e[u][b] = true;
					FOR(b,1,n) if (e[b][a] && b!=u) e[b][u] = true;
				}
				a = p;
			}
			cont = true;
			break;
		}
		if (cont) continue;

		// let u = parent of v in current T
		int u = T[v]; while (removed[u]) u=T[u];

		FOREACH(it, L) if (e[*it][v] && *it!=u) {	// case 3)
			int w=*it;

			// we must reverse the half-directed u--v, from v to u
			if (!half_directed[v]) cerr << "oops, we expected half_directed edge at " << v << endl;			
			output(v, T[v], 1);
			
			e[v][u] = true; e[u][v] = false;

			// edge v->w becomes a tree edge
			T[v] = w;
			half_directed[v] = false;
			
			// moving v on L just before w
			L.erase(L.begin()); 
			FOREACH(it, L) if (*it==w) { L.insert(it, v); break; }
					
			cont = true;
			break;
		}
		if (cont) continue;
		
		// case 2) -- this is a bridge		
		if (!half_directed[v]) cerr << "oops, we expected half_directed edge at " << v << endl;	
		output(v, T[v], 2);
		L.erase(L.begin());
		removed[v] = true;
		
	}
			
	if (L.size() > 1)
		cerr << "Ooops, L not empty at the end\n";
	
}


int main(void) {
	read_data();
	solve();
	return 0;
}
