/*

The sample solution of problem sol - 'Solitaire'.

Straight forward solution is to traverse the space of all chessboard
configurations. This is done using BFS starting from first configuration.

*/

#include <stdio.h>
/* scanf() printf() */

/* Board constants.
Board is stored using two additional guard rows and columns. */
#define BOARD_ROWS	8
#define BOARD_COLUMNS	8
#define FIELDS_IN_ROW	(BOARD_COLUMNS + 2)
#define BOARD_SIZE	(FIELDS_IN_ROW * (BOARD_ROWS + 2))

/* Number of pieces. */
#define PIECES_NR	4

/* Queue constant. The size of queue is 635376 which is the total
configurations number: comb(64,4)=64!/4!(64-4)!. */
#define QUEUE_SIZE	635376

/* Constants for table visited. */
#define VISITED_SIZE	(1 << (6 * PIECES_NR))
#define VISITED_BYTES	(VISITED_SIZE >> 3)

/* Allowed moves. */
#define MOVES_ALLOWED	8

/* Useful macro. */
#define swap(x,y) do {		\
	typeof(x) tmp = x;	\
	x = y;			\
	y = tmp;		\
} while(0)

/* Board fields table. */
char field[BOARD_SIZE];

/* Possible values for field[]. */
enum board_field {
	EMPTY,
	PIECE,
	GUARD
};

/* Representation of single configuration is stored using 4 index positions.
We can treat it as single integer. */
union config {
	unsigned char piece[4];
	unsigned int id;
};

/* Target configuration. */
union config target;

/* Position is represented by one number - index in table board.field. Below
is definition of direction numbers. These are numbers which we add to position
index to get a new position index in given direction. */
#define DIRS	4
const int dir[DIRS] = {
	-1,		/* left */
	1,		/* right */
	-FIELDS_IN_ROW,	/* up */
	FIELDS_IN_ROW	/* down */
};

/* Table of VISITED_SIZE bits. In this table to every possible configuration
responds unique bit which is set if given configuration is reached. */
char visited[VISITED_BYTES];

/* Queue declaration. We store a configuration and number of moves
configuration was reached. */
struct queue {
	int first, last;
	struct {
		union config config;
		int moves;
	} arr[QUEUE_SIZE];
} queue;

/* Field index declaration. For each field on the chessboard
(without artifitial borders) we assign a unique 6-bit integer. */
int field_index[BOARD_SIZE];

/* Initialize board with empty fields and border fields with guards. */
void board_init()
{
	int i;
	for (i = 0; i < BOARD_SIZE; i++)
		field[i] = EMPTY;
	for (i = 1; i <= BOARD_COLUMNS; i++)
		field[i] = GUARD;
	for (i = (BOARD_ROWS + 1) * FIELDS_IN_ROW + 1; i < BOARD_SIZE - 1; i++)
		field[i] = GUARD;
	for (i = 0; i < BOARD_SIZE; i += FIELDS_IN_ROW)
		field[i] = GUARD;
	for (i = BOARD_COLUMNS + 1; i < BOARD_SIZE; i += FIELDS_IN_ROW)
		field[i] = GUARD;
}


/* Queue initialization. */
void queue_init()
{
	queue.first = queue.last = 0;
}

/* queue_empty() queue_put() queue_remove() - stardard queue functions */

int queue_empty()
{
	return queue.first == queue.last;
}

void queue_put(union config config, int moves)
{
	queue.arr[queue.last].config = config;
	queue.arr[queue.last].moves = moves;
	queue.last++;
}

void queue_remove(union config *config, int *moves)
{
	*config = queue.arr[queue.first].config;
	*moves = queue.arr[queue.first].moves;
	queue.first++;
}

/* Initialization of tables visited and field_index. */
void visit_init()
{
	int i, j;
	
	for (i = 0; i < VISITED_BYTES; i++)
		visited[i] = 0;
	
	for (i = 1; i <= BOARD_COLUMNS; i++)
	for (j = 1; j <= BOARD_ROWS; j++)
		field_index[i + j * FIELDS_IN_ROW] =
			(i - 1) + (j - 1) * BOARD_COLUMNS;
}

/* Return a unique 24-bit integer for each configuration. */
int config_index(union config config)
{
	int i;
	int retval = 0;
	
	for (i = 0; i < PIECES_NR; i++)
		retval = (retval << 6) + field_index[config.piece[i]];
	
	return retval;
}

/* Checks whether given configuration was visited and marks it visited. */
int try_visit(union config config)
{
	int idx = config_index(config);
	int byteidx = idx >> 3;
	int bit = 1 << (idx & 7);
	
	if (visited[byteidx] & bit)
		return 0;
	else {
		visited[byteidx] |= bit;
		return 1;
	}
}

/* Read configuration from standard input. */
void config_read(union config *config)
{
	int i;
	
	for (i = 0; i < 4 ; i++) {
		int x, y;
		scanf("%d%d", &x, &y);
		config->piece[i] = y * FIELDS_IN_ROW + x;
	}
}

/* Configuration sorting. Four piece positions stored in
configuration are sorted using 4 or 5 comparisons.
Configurations have to be sorted because function config_index have to return
unique indexes for identical configurations. */
void config_sort(union config *config)
{
	int i, j;
	
	for (i = 0; i < PIECES_NR - 1; i++)
	for (j = i + 1; j < PIECES_NR; j++)
		if (config->piece[j] < config->piece[i])
			swap(config->piece[i], config->piece[j]);
}

int search(union config config, int moves)
{
	int i;
	int d;
	
	moves++;
	
	for (i = 0; i < PIECES_NR; i++)
		field[(int)config.piece[i]] = PIECE;
	
	for (d = 0; d < DIRS; d++)
	for (i = 0; i < PIECES_NR; i++) {
		int position = config.piece[i];
		int new_position = position + dir[d];
		union config c;
		if (field[new_position] == GUARD)
			continue;
		if (field[new_position] == PIECE) {
			new_position += dir[d];
			if (field[new_position] != EMPTY)
				continue;
		}
		
		c = config;
		c.piece[i] = new_position;
		config_sort(&c);
		if (c.id == target.id)
			return 1;
		
		if (moves == MOVES_ALLOWED)
			continue;
		
		swap(field[position], field[new_position]);
	
		if (try_visit(c))
			queue_put(c, moves);
		
		swap(field[position], field[new_position]);
	}
	
	for (i = 0; i < PIECES_NR; i++)
		field[(int)config.piece[i]] = EMPTY;
	
	return 0;
}

void solve()
{
	union config config;
	int found = 0;
	
	queue_init();
	board_init();
	visit_init();
	
	config_read(&config);
	config_sort(&config);
	config_read(&target);
	config_sort(&target);
	
	if (config.id == target.id)
		found = 1;
	
	queue_put(config, 0);
	try_visit(config);
	while (!found && !queue_empty()) {
		int moves;
		queue_remove(&config, &moves);
		found = search(config, moves);
	}
	
	if (found)
		printf("YES\n");
	else
		printf("NO\n");
}

int main()
{
	solve();
	
	return 0;
}
